==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildSpecFluentImpl<A extends BuildSpecFluent<A>> extends BaseFluent<A> implements BuildSpecFluent<A>{
  public BuildSpecFluentImpl() {
  }
  public BuildSpecFluentImpl(BuildSpec instance) {
    this.withAdditionalTrustedCA(instance.getAdditionalTrustedCA()); 
    this.withBuildDefaults(instance.getBuildDefaults()); 
    this.withBuildOverrides(instance.getBuildOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ConfigMapNameReferenceBuilder additionalTrustedCA;
  private BuildDefaultsBuilder buildDefaults;
  private BuildOverridesBuilder buildOverrides;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAdditionalTrustedCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getAdditionalTrustedCA() {
    return this.additionalTrustedCA!=null ?this.additionalTrustedCA.build():null;
  }
  public ConfigMapNameReference buildAdditionalTrustedCA() {
    return this.additionalTrustedCA!=null ?this.additionalTrustedCA.build():null;
  }
  public A withAdditionalTrustedCA(ConfigMapNameReference additionalTrustedCA) {
    _visitables.get("additionalTrustedCA").remove(this.additionalTrustedCA);
    if (additionalTrustedCA!=null){ this.additionalTrustedCA= new ConfigMapNameReferenceBuilder(additionalTrustedCA); _visitables.get("additionalTrustedCA").add(this.additionalTrustedCA);} else { this.additionalTrustedCA = null; _visitables.get("additionalTrustedCA").remove(this.additionalTrustedCA); } return (A) this;
  }
  public Boolean hasAdditionalTrustedCA() {
    return this.additionalTrustedCA != null;
  }
  public A withNewAdditionalTrustedCA(String name) {
    return (A)withAdditionalTrustedCA(new ConfigMapNameReference(name));
  }
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCA() {
    return new BuildSpecFluentImpl.AdditionalTrustedCANestedImpl();
  }
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCALike(ConfigMapNameReference item) {
    return new BuildSpecFluentImpl.AdditionalTrustedCANestedImpl(item);
  }
  public BuildSpecFluent.AdditionalTrustedCANested<A> editAdditionalTrustedCA() {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA());
  }
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCA() {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA() != null ? getAdditionalTrustedCA(): new ConfigMapNameReferenceBuilder().build());
  }
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCALike(ConfigMapNameReference item) {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA() != null ? getAdditionalTrustedCA(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuildDefaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildDefaults getBuildDefaults() {
    return this.buildDefaults!=null ?this.buildDefaults.build():null;
  }
  public BuildDefaults buildBuildDefaults() {
    return this.buildDefaults!=null ?this.buildDefaults.build():null;
  }
  public A withBuildDefaults(BuildDefaults buildDefaults) {
    _visitables.get("buildDefaults").remove(this.buildDefaults);
    if (buildDefaults!=null){ this.buildDefaults= new BuildDefaultsBuilder(buildDefaults); _visitables.get("buildDefaults").add(this.buildDefaults);} else { this.buildDefaults = null; _visitables.get("buildDefaults").remove(this.buildDefaults); } return (A) this;
  }
  public Boolean hasBuildDefaults() {
    return this.buildDefaults != null;
  }
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaults() {
    return new BuildSpecFluentImpl.BuildDefaultsNestedImpl();
  }
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaultsLike(BuildDefaults item) {
    return new BuildSpecFluentImpl.BuildDefaultsNestedImpl(item);
  }
  public BuildSpecFluent.BuildDefaultsNested<A> editBuildDefaults() {
    return withNewBuildDefaultsLike(getBuildDefaults());
  }
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaults() {
    return withNewBuildDefaultsLike(getBuildDefaults() != null ? getBuildDefaults(): new BuildDefaultsBuilder().build());
  }
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaultsLike(BuildDefaults item) {
    return withNewBuildDefaultsLike(getBuildDefaults() != null ? getBuildDefaults(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOverrides getBuildOverrides() {
    return this.buildOverrides!=null ?this.buildOverrides.build():null;
  }
  public BuildOverrides buildBuildOverrides() {
    return this.buildOverrides!=null ?this.buildOverrides.build():null;
  }
  public A withBuildOverrides(BuildOverrides buildOverrides) {
    _visitables.get("buildOverrides").remove(this.buildOverrides);
    if (buildOverrides!=null){ this.buildOverrides= new BuildOverridesBuilder(buildOverrides); _visitables.get("buildOverrides").add(this.buildOverrides);} else { this.buildOverrides = null; _visitables.get("buildOverrides").remove(this.buildOverrides); } return (A) this;
  }
  public Boolean hasBuildOverrides() {
    return this.buildOverrides != null;
  }
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverrides() {
    return new BuildSpecFluentImpl.BuildOverridesNestedImpl();
  }
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverridesLike(BuildOverrides item) {
    return new BuildSpecFluentImpl.BuildOverridesNestedImpl(item);
  }
  public BuildSpecFluent.BuildOverridesNested<A> editBuildOverrides() {
    return withNewBuildOverridesLike(getBuildOverrides());
  }
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverrides() {
    return withNewBuildOverridesLike(getBuildOverrides() != null ? getBuildOverrides(): new BuildOverridesBuilder().build());
  }
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverridesLike(BuildOverrides item) {
    return withNewBuildOverridesLike(getBuildOverrides() != null ? getBuildOverrides(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BuildSpecFluentImpl that = (BuildSpecFluentImpl) o;
    if (additionalTrustedCA != null ? !additionalTrustedCA.equals(that.additionalTrustedCA) :that.additionalTrustedCA != null) return false;
    if (buildDefaults != null ? !buildDefaults.equals(that.buildDefaults) :that.buildDefaults != null) return false;
    if (buildOverrides != null ? !buildOverrides.equals(that.buildOverrides) :that.buildOverrides != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(additionalTrustedCA,  buildDefaults,  buildOverrides,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (additionalTrustedCA != null) { sb.append("additionalTrustedCA:"); sb.append(additionalTrustedCA + ","); }
    if (buildDefaults != null) { sb.append("buildDefaults:"); sb.append(buildDefaults + ","); }
    if (buildOverrides != null) { sb.append("buildOverrides:"); sb.append(buildOverrides + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AdditionalTrustedCANestedImpl<N> extends ConfigMapNameReferenceFluentImpl<BuildSpecFluent.AdditionalTrustedCANested<N>> implements BuildSpecFluent.AdditionalTrustedCANested<N>,Nested<N>{
    AdditionalTrustedCANestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    AdditionalTrustedCANestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withAdditionalTrustedCA(builder.build());
    }
    public N endAdditionalTrustedCA() {
      return and();
    }
    
  }
  class BuildDefaultsNestedImpl<N> extends BuildDefaultsFluentImpl<BuildSpecFluent.BuildDefaultsNested<N>> implements BuildSpecFluent.BuildDefaultsNested<N>,Nested<N>{
    BuildDefaultsNestedImpl(BuildDefaults item) {
      this.builder = new BuildDefaultsBuilder(this, item);
    }
    BuildDefaultsNestedImpl() {
      this.builder = new BuildDefaultsBuilder(this);
    }
    BuildDefaultsBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withBuildDefaults(builder.build());
    }
    public N endBuildDefaults() {
      return and();
    }
    
  }
  class BuildOverridesNestedImpl<N> extends BuildOverridesFluentImpl<BuildSpecFluent.BuildOverridesNested<N>> implements BuildSpecFluent.BuildOverridesNested<N>,Nested<N>{
    BuildOverridesNestedImpl(BuildOverrides item) {
      this.builder = new BuildOverridesBuilder(this, item);
    }
    BuildOverridesNestedImpl() {
      this.builder = new BuildOverridesBuilder(this);
    }
    BuildOverridesBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withBuildOverrides(builder.build());
    }
    public N endBuildOverrides() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildSpecFluentImpl<A extends BuildSpecFluent<A>> extends BaseFluent<A> implements BuildSpecFluent<A>{
  public BuildSpecFluentImpl() {
  }
  public BuildSpecFluentImpl(BuildSpec instance) {
    if (instance != null) {
      this.withAdditionalTrustedCA(instance.getAdditionalTrustedCA());
      this.withBuildDefaults(instance.getBuildDefaults());
      this.withBuildOverrides(instance.getBuildOverrides());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ConfigMapNameReferenceBuilder additionalTrustedCA;
  private BuildDefaultsBuilder buildDefaults;
  private BuildOverridesBuilder buildOverrides;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAdditionalTrustedCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getAdditionalTrustedCA() {
    return this.additionalTrustedCA!=null ?this.additionalTrustedCA.build():null;
  }
  public ConfigMapNameReference buildAdditionalTrustedCA() {
    return this.additionalTrustedCA!=null ?this.additionalTrustedCA.build():null;
  }
  public A withAdditionalTrustedCA(ConfigMapNameReference additionalTrustedCA) {
    _visitables.get("additionalTrustedCA").remove(this.additionalTrustedCA);
    if (additionalTrustedCA!=null){ this.additionalTrustedCA= new ConfigMapNameReferenceBuilder(additionalTrustedCA); _visitables.get("additionalTrustedCA").add(this.additionalTrustedCA);} else { this.additionalTrustedCA = null; _visitables.get("additionalTrustedCA").remove(this.additionalTrustedCA); } return (A) this;
  }
  public Boolean hasAdditionalTrustedCA() {
    return this.additionalTrustedCA != null;
  }
  public A withNewAdditionalTrustedCA(String name) {
    return (A)withAdditionalTrustedCA(new ConfigMapNameReference(name));
  }
  public BuildSpecFluentImpl.AdditionalTrustedCANested<A> withNewAdditionalTrustedCA() {
    return new BuildSpecFluentImpl.AdditionalTrustedCANestedImpl();
  }
  public BuildSpecFluentImpl.AdditionalTrustedCANested<A> withNewAdditionalTrustedCALike(ConfigMapNameReference item) {
    return new BuildSpecFluentImpl.AdditionalTrustedCANestedImpl(item);
  }
  public BuildSpecFluentImpl.AdditionalTrustedCANested<A> editAdditionalTrustedCA() {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA());
  }
  public BuildSpecFluentImpl.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCA() {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA() != null ? getAdditionalTrustedCA(): new ConfigMapNameReferenceBuilder().build());
  }
  public BuildSpecFluentImpl.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCALike(ConfigMapNameReference item) {
    return withNewAdditionalTrustedCALike(getAdditionalTrustedCA() != null ? getAdditionalTrustedCA(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuildDefaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildDefaults getBuildDefaults() {
    return this.buildDefaults!=null ?this.buildDefaults.build():null;
  }
  public BuildDefaults buildBuildDefaults() {
    return this.buildDefaults!=null ?this.buildDefaults.build():null;
  }
  public A withBuildDefaults(BuildDefaults buildDefaults) {
    _visitables.get("buildDefaults").remove(this.buildDefaults);
    if (buildDefaults!=null){ this.buildDefaults= new BuildDefaultsBuilder(buildDefaults); _visitables.get("buildDefaults").add(this.buildDefaults);} else { this.buildDefaults = null; _visitables.get("buildDefaults").remove(this.buildDefaults); } return (A) this;
  }
  public Boolean hasBuildDefaults() {
    return this.buildDefaults != null;
  }
  public BuildSpecFluentImpl.BuildDefaultsNested<A> withNewBuildDefaults() {
    return new BuildSpecFluentImpl.BuildDefaultsNestedImpl();
  }
  public BuildSpecFluentImpl.BuildDefaultsNested<A> withNewBuildDefaultsLike(BuildDefaults item) {
    return new BuildSpecFluentImpl.BuildDefaultsNestedImpl(item);
  }
  public BuildSpecFluentImpl.BuildDefaultsNested<A> editBuildDefaults() {
    return withNewBuildDefaultsLike(getBuildDefaults());
  }
  public BuildSpecFluentImpl.BuildDefaultsNested<A> editOrNewBuildDefaults() {
    return withNewBuildDefaultsLike(getBuildDefaults() != null ? getBuildDefaults(): new BuildDefaultsBuilder().build());
  }
  public BuildSpecFluentImpl.BuildDefaultsNested<A> editOrNewBuildDefaultsLike(BuildDefaults item) {
    return withNewBuildDefaultsLike(getBuildDefaults() != null ? getBuildDefaults(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOverrides getBuildOverrides() {
    return this.buildOverrides!=null ?this.buildOverrides.build():null;
  }
  public BuildOverrides buildBuildOverrides() {
    return this.buildOverrides!=null ?this.buildOverrides.build():null;
  }
  public A withBuildOverrides(BuildOverrides buildOverrides) {
    _visitables.get("buildOverrides").remove(this.buildOverrides);
    if (buildOverrides!=null){ this.buildOverrides= new BuildOverridesBuilder(buildOverrides); _visitables.get("buildOverrides").add(this.buildOverrides);} else { this.buildOverrides = null; _visitables.get("buildOverrides").remove(this.buildOverrides); } return (A) this;
  }
  public Boolean hasBuildOverrides() {
    return this.buildOverrides != null;
  }
  public BuildSpecFluentImpl.BuildOverridesNested<A> withNewBuildOverrides() {
    return new BuildSpecFluentImpl.BuildOverridesNestedImpl();
  }
  public BuildSpecFluentImpl.BuildOverridesNested<A> withNewBuildOverridesLike(BuildOverrides item) {
    return new BuildSpecFluentImpl.BuildOverridesNestedImpl(item);
  }
  public BuildSpecFluentImpl.BuildOverridesNested<A> editBuildOverrides() {
    return withNewBuildOverridesLike(getBuildOverrides());
  }
  public BuildSpecFluentImpl.BuildOverridesNested<A> editOrNewBuildOverrides() {
    return withNewBuildOverridesLike(getBuildOverrides() != null ? getBuildOverrides(): new BuildOverridesBuilder().build());
  }
  public BuildSpecFluentImpl.BuildOverridesNested<A> editOrNewBuildOverridesLike(BuildOverrides item) {
    return withNewBuildOverridesLike(getBuildOverrides() != null ? getBuildOverrides(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildSpecFluentImpl that = (BuildSpecFluentImpl) o;
    if (!java.util.Objects.equals(additionalTrustedCA, that.additionalTrustedCA)) return false;

    if (!java.util.Objects.equals(buildDefaults, that.buildDefaults)) return false;

    if (!java.util.Objects.equals(buildOverrides, that.buildOverrides)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(additionalTrustedCA,  buildDefaults,  buildOverrides,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (additionalTrustedCA != null) { sb.append("additionalTrustedCA:"); sb.append(additionalTrustedCA + ","); }
    if (buildDefaults != null) { sb.append("buildDefaults:"); sb.append(buildDefaults + ","); }
    if (buildOverrides != null) { sb.append("buildOverrides:"); sb.append(buildOverrides + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AdditionalTrustedCANestedImpl<N> extends ConfigMapNameReferenceFluentImpl<BuildSpecFluentImpl.AdditionalTrustedCANested<N>> implements BuildSpecFluentImpl.AdditionalTrustedCANested<N>,Nested<N>{
    AdditionalTrustedCANestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    AdditionalTrustedCANestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withAdditionalTrustedCA(builder.build());
    }
    public N endAdditionalTrustedCA() {
      return and();
    }
    
  }
  class BuildDefaultsNestedImpl<N> extends BuildDefaultsFluentImpl<BuildSpecFluentImpl.BuildDefaultsNested<N>> implements BuildSpecFluentImpl.BuildDefaultsNested<N>,Nested<N>{
    BuildDefaultsNestedImpl(BuildDefaults item) {
      this.builder = new BuildDefaultsBuilder(this, item);
    }
    BuildDefaultsNestedImpl() {
      this.builder = new BuildDefaultsBuilder(this);
    }
    BuildDefaultsBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withBuildDefaults(builder.build());
    }
    public N endBuildDefaults() {
      return and();
    }
    
  }
  class BuildOverridesNestedImpl<N> extends BuildOverridesFluentImpl<BuildSpecFluentImpl.BuildOverridesNested<N>> implements BuildSpecFluentImpl.BuildOverridesNested<N>,Nested<N>{
    BuildOverridesNestedImpl(BuildOverrides item) {
      this.builder = new BuildOverridesBuilder(this, item);
    }
    BuildOverridesNestedImpl() {
      this.builder = new BuildOverridesBuilder(this);
    }
    BuildOverridesBuilder builder;
    public N and() {
      return (N) BuildSpecFluentImpl.this.withBuildOverrides(builder.build());
    }
    public N endBuildOverrides() {
      return and();
    }
    
  }
  
}
